@@ -12,7 +12,7 @@ import urllib.parse
 from json.decoder import JSONDecodeError
 from pathlib import Path
 from urllib import parse
-from urllib.parse import unquote
+from urllib.parse import unquote, urljoin
 
 from pipenv.utils.constants import VCS_LIST
 
@@ -240,7 +240,9 @@ class Project:
             session = self.sessions[source["name"]]
         else:
             session = get_requests_session(
-                self.s.PIPENV_MAX_RETRIES, source.get("verify_ssl", True)
+                self.s.PIPENV_MAX_RETRIES,
+                source.get("verify_ssl", True),
+                cache_dir=self.s.PIPENV_CACHE_DIR,
             )
             self.sessions[source["name"]] = session
         return session
@@ -315,10 +317,11 @@ class Project:
                     if params_dict.get(FAVORITE_HASH):
                         collected_hashes.add(params_dict[FAVORITE_HASH][0])
                     else:  # Fallback to downloading the file to obtain hash
-                        if source["url"] not in package_url:
-                            package_url = f"{source['url']}{package_url}"
+                        package_url = urljoin(source["url"], package_url)
                         link = Link(package_url)
-                        collected_hashes.add(self.get_file_hash(session, link))
+                        file_hash = self.get_file_hash(session, link)
+                        if file_hash:
+                            collected_hashes.add(file_hash)
             return self.prepend_hash_types(collected_hashes, FAVORITE_HASH)
         except (ValueError, KeyError, ConnectionError):
             if self.s.is_verbose():
@@ -334,6 +337,8 @@ class Project:
         h = hashlib.new(FAVORITE_HASH)
         err.print(f"Downloading file {link.filename} to obtain hash...")
         with open_file(link.url, session) as fp:
+            if fp is None:
+                return None
             for chunk in iter(lambda: fp.read(8096), b""):
                 h.update(chunk)
         return f"{h.name}:{h.hexdigest()}"
