@@ -4,10 +4,13 @@ from collections.abc import Mapping
 
 from pipenv.patched.pip._vendor.packaging.utils import canonicalize_name
 from pipenv.routines.lock import do_lock
-from pipenv.utils.dependencies import pep423_name
+from pipenv.utils.dependencies import (
+    as_pipfile,
+    expansive_install_req_from_line,
+    get_version,
+    pep423_name,
+)
 from pipenv.vendor import click
-from pipenv.vendor.requirementslib.models.requirements import Requirement
-from pipenv.vendor.requirementslib.models.utils import get_version
 
 
 def do_outdated(project, pypi_mirror=None, pre=False, clear=False):
@@ -26,8 +29,11 @@ def do_outdated(project, pypi_mirror=None, pre=False, clear=False):
         for name, deps in project.environment.reverse_dependencies().items()
     }
     for result in installed_packages:
-        dep = Requirement.from_line(str(result.as_requirement()))
-        packages.update(dep.as_pipfile())
+        dep = expansive_install_req_from_line(
+            str(result.as_requirement()), expand_env=True
+        )
+        packages.update(as_pipfile(dep))
+
     updated_packages = {}
     lockfile = do_lock(
         project, clear=clear, pre=pre, write=False, pypi_mirror=pypi_mirror
@@ -64,16 +70,15 @@ def do_outdated(project, pypi_mirror=None, pre=False, clear=False):
                 )
                 rdeps = reverse_deps.get(canonicalize_name(package))
                 if isinstance(rdeps, Mapping) and "required" in rdeps:
-                    required = " {} required".format(rdeps["required"])
+                    required = " {rdeps['required']} required"
                 if version:
                     pipfile_version_text = f" ({version} set in Pipfile)"
                 else:
                     pipfile_version_text = " (Unpinned in Pipfile)"
                 click.secho(
-                    "Skipped Update of Package {!s}: {!s} installed,{!s}{!s}, "
-                    "{!s} available.".format(
-                        package, old_version, required, pipfile_version_text, new_version
-                    ),
+                    f"Skipped Update of Package {package!s}:"
+                    f" {old_version!s} installed,{required!s}{pipfile_version_text!s}, "
+                    f"{new_version!s} available.",
                     fg="yellow",
                     err=True,
                 )
@@ -82,8 +87,6 @@ def do_outdated(project, pypi_mirror=None, pre=False, clear=False):
         sys.exit(0)
     for package, new_version, old_version in outdated:
         click.echo(
-            "Package {!r} out-of-date: {!r} installed, {!r} available.".format(
-                package, old_version, new_version
-            )
+            f"Package {package!r} out-of-date: {old_version!r} installed, {new_version!r} available."
         )
     sys.exit(bool(outdated))
