@@ -185,7 +185,7 @@ def unearth_hashes_for_dep(project, dep):
             break
 
     # 1 Try to get hashes directly form index
-    install_req, markers = install_req_from_pipfile(dep["name"], dep)
+    install_req, markers, _ = install_req_from_pipfile(dep["name"], dep)
     if not install_req or not install_req.req:
         return []
     if "https://pypi.org/simple/" in index_url:
@@ -959,18 +959,32 @@ def expansive_install_req_from_line(
 
 def install_req_from_pipfile(name, pipfile):
     _pipfile = {}
+    vcs = None
     if hasattr(pipfile, "keys"):
         _pipfile = dict(pipfile).copy()
+    else:
+        vcs = next(iter([vcs for vcs in VCS_LIST if pipfile.startswith(f"{vcs}+")]), None)
+        if vcs is not None:
+            _pipfile[vcs] = pipfile
 
     extras = _pipfile.get("extras", [])
     extras_str = ""
     if extras:
         extras_str = f"[{','.join(extras)}]"
-    vcs = next(iter([vcs for vcs in VCS_LIST if vcs in _pipfile]), None)
+    if not vcs:
+        vcs = next(iter([vcs for vcs in VCS_LIST if vcs in _pipfile]), None)
 
     if vcs:
-        _pipfile["vcs"] = vcs
-        req_str = f"{_pipfile[vcs]}{_pipfile.get('ref', '')}{extras_str}"
+        vcs_url = _pipfile[vcs]
+        fallback_ref = ""
+        if ("ssh://" in vcs_url and vcs_url.count("@") >= 2) or (
+            "ssh://" not in vcs_url and "@" in vcs_url
+        ):
+            vcs_url_parts = vcs_url.rsplit("@", 1)
+            if re.match(r"^[\w\.]+$", vcs_url_parts[1]):
+                vcs_url = vcs_url_parts[0]
+                fallback_ref = vcs_url_parts[1]
+        req_str = f"{vcs_url}@{_pipfile.get('ref', fallback_ref)}{extras_str}"
         if not req_str.startswith(f"{vcs}+"):
             req_str = f"{vcs}+{req_str}"
         if f"{vcs}+file://" in req_str:
@@ -1000,12 +1014,11 @@ def install_req_from_pipfile(name, pipfile):
         expand_env=True,
     )
     markers = PipenvMarkers.from_pipfile(name, _pipfile)
-    return install_req, markers
+    return install_req, markers, req_str
 
 
 def from_pipfile(name, pipfile):
-    install_req, markers = install_req_from_pipfile(name, pipfile)
-
+    install_req, markers, req_str = install_req_from_pipfile(name, pipfile)
     if markers:
         markers = str(markers)
         install_req.markers = Marker(markers)
