@@ -156,6 +156,16 @@ def requirement_from_lockfile(
         if vcs in package_info:
             url = package_info[vcs]
             ref = package_info.get("ref", "")
+            if ("ssh://" in url and url.count("@") >= 2) or (
+                "ssh://" not in url and "@" in url
+            ):
+                url_parts = url.rsplit("@", 1)
+                # Check if the second part matches the criteria to be a ref (vcs URLs would likely have a /)
+                if re.match(r"^[\w\.]+$", url_parts[1]):
+                    url = url_parts[0]
+                    if not ref:
+                        ref = url_parts[1]
+
             extras = (
                 "[{}]".format(",".join(package_info.get("extras", [])))
                 if "extras" in package_info
@@ -163,7 +173,7 @@ def requirement_from_lockfile(
             )
             include_vcs = "" if f"{vcs}+" in url else f"{vcs}+"
             egg_fragment = "" if "#egg=" in url else f"#egg={package_name}"
-            ref_str = "" if f"@{ref}" in url else f"@{ref}"
+            ref_str = "" if not ref or f"@{ref}" in url else f"@{ref}"
             if is_editable_path(url) or "file://" in url:
                 pip_line = f"-e {include_vcs}{url}{ref_str}{egg_fragment}{extras}"
             else:
